import './main1.js';
export { asdf as dep } from 'external';
